<?xml version='1.0' ?>
<!--This stylesheet converts XMI exported by TogetherEC specifically XMI 1.2 for UML 1.4(OMG)	-->
<!--Author : Tor Neple																			-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:UML="//org.omg/UML/1.3" xmlns:uml="http://www.eclipse.org/uml2/1.0.0/UML" exclude-result-prefixes="UML" xmlns:xmi="http://www.omg.org/XMI">
	<xsl:output method="xml" indent="yes"/>
	
	<xsl:template match="text()|@*">
		<xsl:value-of select="."/>
	</xsl:template>
	
	<xsl:template match="text()|@*"/>

	<xsl:template match="/XMI/XMI.content/UML:Model">
		<uml:Model>
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:attribute name="xmi:id">
				<xsl:value-of select="@xmi.id"/>
			</xsl:attribute>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:Class"/>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:Interface"/>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:DataType"/>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:Package|UML:Namespace.ownedElement/UML:Subsystem"/>
		
		</uml:Model>
	</xsl:template>

	<xsl:template match="UML:DataType">
		<uml:ownedMember xmi:type="uml:PrimitiveType">
			<xsl:attribute name="xmi:id">
				<xsl:value-of select="@xmi.id"/>
			</xsl:attribute>
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
		</uml:ownedMember>
	</xsl:template>

	<xsl:template match="UML:Package|UML:Subsystem">
		<uml:ownedMember>
			<xsl:attribute name="xmi:type">
				<xsl:text>uml:Package</xsl:text>
			</xsl:attribute>
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:attribute name="xmi:id">
				<xsl:value-of select="@xmi.id"/>
			</xsl:attribute>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:Class"/>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:Interface"/>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:DataType"/>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:Association"/>
			<xsl:apply-templates select="UML:Namespace.ownedElement/UML:Package|UML:Namespace.ownedElement/UML:Subsystem"/>
		</uml:ownedMember>
	</xsl:template>

	<xsl:template match="UML:Association">
		
		<xsl:variable name="connections" select="UML:Association.connection"/>
		<xsl:variable name="longstring">
			<xsl:for-each select="$connections/UML:AssociationEnd">
					<xsl:value-of select="concat(@xmi.id, ' ')"/>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="memberEndString"/>
		<uml:ownedMember xmi:type="uml:Association">
			<xsl:attribute name="xmi:id">
				<xsl:value-of select="@xmi.id"/>
			</xsl:attribute>
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:attribute name="memberEnd">
				<xsl:value-of select="normalize-space($longstring)"/>
			</xsl:attribute>
		</uml:ownedMember>
	</xsl:template>


	<xsl:template match="UML:Class">
		<!-- ****************** CLASS ********************* -->
		<xsl:variable name="classID" select="@xmi.id"/>
		<xsl:element name="uml:ownedMember">
			<xsl:attribute name="xmi:type">
				<xsl:text>uml:Class</xsl:text>
			</xsl:attribute>
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:attribute name="xmi:id">
				<xsl:value-of select="@xmi.id"/>
			</xsl:attribute>
			
			<xsl:variable name="inheritsID" select="UML:Namespace.ownedElement/UML:Generalization/UML:Generalization.parent/UML:GeneralizableElement/@xmi.idref"/>

		<xsl:if test="string-length($inheritsID)!=0">
			<xsl:element name="generalization">
				<xsl:attribute name="general">
					<xsl:value-of select="$inheritsID"/>
				</xsl:attribute>
			</xsl:element>
		</xsl:if>

		
		
			<xsl:call-template name="XMI1_2_classBody">
				<xsl:with-param name="classID" select="$classID"/>
			</xsl:call-template>

		


		</xsl:element>
	</xsl:template>

	<xsl:template name="XMI1_2_classBody">

		<xsl:param name="classID"/>
		<!--Inheritance-->

		<xsl:attribute name="isAbstract">
			<xsl:value-of select="@isAbstract"/>
		</xsl:attribute>

		<!--Outputs the stereotype according to the strange RS{A|M} format-->
		<xsl:if test="string-length(@stereotype)!=0">
			<xsl:call-template name="getStereotype">
				<xsl:with-param name="stereotype_id" select="@stereotype"/>
			</xsl:call-template>
		</xsl:if>


		
		<!-- Attributes -->
		<xsl:apply-templates select="UML:Classifier.feature/UML:Attribute"/>

		<!-- Associatons-->
		<xsl:call-template name="associationsForClass_12">
			<xsl:with-param name="id" select="$classID"/>
		</xsl:call-template>

		<!-- Operations -->
		<xsl:apply-templates select="UML:Classifier.feature/UML:Operation"/>
		

	</xsl:template>

 
 	<xsl:template match="UML:Operation">
		<!-- Class operations -->
		<xsl:variable name="name" select="concat(@name, UML:ModelElement.name)"/>
		<xsl:variable name="opID" select="@xmi.id"/>
		<xsl:variable name="visibility" select="concat(@visibility, UML:ModelElement.visibility/@xmi.value)"/>
		<xsl:variable name="ownerScope" select="concat(@ownerScope, UML:Feature.ownerScope/@xmi.value)"/>
		<xsl:variable name="isQuery" select="concat(@isQuery, UML:BehavioralFeature.isQuery/@xmi.value)"/>
		<xsl:variable name="isLeaf" select="concat(@isLeaf, UML:Operation.isLeaf/@xmi.value)"/>
		<xsl:variable name="isAbstract" select="concat(@isAbstract, UML:Operation.isAbstract/@xmi.value)"/>
		<xsl:variable name="returnTypeNode" select="UML:BehavioralFeature.parameter/UML:Parameter[@kind='return' or UML:Parameter.kind/@xmi.value='return']"/>
		<xsl:variable name="returnTypeID">
			<xsl:value-of select="concat($returnTypeNode/@type, $returnTypeNode/UML:Parameter.type//@xmi.idref)"/>
		</xsl:variable>
		<ownedOperation>
			<xsl:attribute name="xmi:id">
				<xsl:value-of select="@xmi.id"/>
			</xsl:attribute>
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:attribute name="visibility">
				<xsl:value-of select="@visibility"/>
			</xsl:attribute>

			<xsl:if test="string-length($returnTypeID) &gt; 0">
				<xsl:element name="returnResult">
					<xsl:attribute name="xmi:id">
						<xsl:value-of select="$returnTypeNode/@xmi.id"/>
					</xsl:attribute>
					<xsl:attribute name="name">
						<xsl:value-of select="$returnTypeNode/@name"/>
					</xsl:attribute>
					<xsl:attribute name="type">
						<xsl:value-of select="$returnTypeID"/>
					</xsl:attribute>
				</xsl:element>
			</xsl:if>
			<xsl:apply-templates select="UML:BehavioralFeature.parameter/UML:Parameter"/>
		</ownedOperation>
	</xsl:template>

	<xsl:template match="UML:Parameter">
		<xsl:variable name="kind" select="concat(@kind, UML:Parameter.kind/@xmi.value)"/>
		<xsl:variable name="name" select="concat(@name, UML:ModelElement.name)"/>
		<xsl:variable name="typeID">
			<xsl:value-of select="concat(UML:Parameter.type//@xmi.idref, @type)"/>
		</xsl:variable>

		<xsl:if test="$kind != 'return'">
			<xsl:element name="ownedParameter">
				<xsl:attribute name="name">
					<xsl:value-of select="$name"/>
				</xsl:attribute>
				<xsl:attribute name="xmi:id">
					<xsl:value-of select="@xmi.id"/>
				</xsl:attribute>
				<xsl:attribute name="type">
					<xsl:value-of select="$typeID"/>
				</xsl:attribute>
				<xsl:attribute name="direction">
					<xsl:value-of select="$kind"/>
				</xsl:attribute>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<xsl:template match="UML:Attribute">
		<!-- Class attributes -->
		<xsl:variable name="multi_lower" select="concat(.//UML:MultiplicityRange/@lower, .//UML:MultiplicityRange.lower)"/>
		<xsl:variable name="multi_upper" select="concat(.//UML:MultiplicityRange/@upper, .//UML:MultiplicityRange.upper)"/>
		<xsl:variable name="attrName" select="concat(@name, UML:ModelElement.name)"/>
		<xsl:variable name="attrID" select="@xmi.id"/>
		
		<xsl:element name="ownedAttribute">
			<xsl:attribute name="xmi:id">
				<xsl:value-of select="$attrID"/>
			</xsl:attribute>
			<xsl:attribute name="name">
				<xsl:value-of select="$attrName"/>
			</xsl:attribute>
			<xsl:attribute name="type">
				<xsl:value-of select="concat(UML:StructuralFeature.type/UML:Classifier/UML:Namespace.ownedElement/UML:DataType/@xmi.idref,UML:StructuralFeature.type/Foundation.Core.Classifier/@xmi.idref)"/>
			</xsl:attribute>
			<xsl:attribute name="visibility">
				<xsl:value-of select="@visibility"/>
			</xsl:attribute>
			<!-- Stereotypes-->
			<xsl:if test="string-length(@stereotype)!=0">
				<xsl:call-template name="getStereotype">
					<xsl:with-param name="stereotype_id">
						<xsl:value-of select="@stereotype"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
		</xsl:element>
	</xsl:template>

	<xsl:template name="getStereotype">
		<!-- XMI 1.2-->
		<xsl:param name="stereotype_id"/>
		<xsl:element name="eAnnotations">
			<xsl:attribute name="source">
				<xsl:text>keywords</xsl:text>
			</xsl:attribute>
			<xsl:element name="details">
				<xsl:attribute name="key">
					<xsl:value-of select="//UML:Stereotype[@xmi.id=$stereotype_id]/@name"/>		
				</xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>


	<xsl:template name="associationsForClass_12">
		<xsl:param name="id"/>

		<!-- UML1.4: -->
		<xsl:for-each select="//UML:AssociationEnd/UML:AssociationEnd.participant/*[@xmi.idref = $id]">
			<!-- Choose only association ends where navigable is true. -->
			<xsl:variable name="thisEnd" select="../.."/>
			<xsl:variable name="thisEndId" select="$thisEnd/@xmi.id"/>
			<xsl:variable name="otherEnd" select="../../../UML:AssociationEnd[@xmi.id != $thisEndId]"/>
			<xsl:variable name="otherEndId" select="$otherEnd/@xmi.id"/>
			<xsl:if test="$otherEnd/@isNavigable = 'true'">
				<xsl:variable name="name">
					<xsl:choose>
						<xsl:when test="string-length($otherEnd/@name)&gt;0">
							<xsl:value-of select="$otherEnd/@name"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>MissingRoleName</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:element name="ownedAttribute">
					<xsl:attribute name="name">
						<xsl:value-of select="$name"/>
					</xsl:attribute>
					<xsl:attribute name="xmi:id">
						<xsl:call-template name="XMI1_2_translateID"><xsl:with-param name="id" select="$otherEnd/@xmi.id"/></xsl:call-template>
					</xsl:attribute>
					<xsl:attribute name="type">
						<xsl:call-template name="XMI1_2_translateID"><xsl:with-param name="id" select="$otherEnd/UML:AssociationEnd.participant/*/@xmi.idref"/></xsl:call-template>
					</xsl:attribute>
					<xsl:attribute name="association">
						<!-- Watch out for reverse tree traversal -->
						<xsl:value-of select="../../../../@xmi.id"/>
					</xsl:attribute>
					<xsl:element name="upperValue">
						<xsl:call-template name="dumpCardinalityAttribs">
							<xsl:with-param name="cardinality" select="$otherEnd//UML:MultiplicityRange/@upper"/>
						</xsl:call-template>
					</xsl:element>
					<xsl:element name="lowerValue">
						<xsl:call-template name="dumpCardinalityAttribs">
							<xsl:with-param name="cardinality" select="$otherEnd//UML:MultiplicityRange/@lower"/>
						</xsl:call-template>
					</xsl:element>
					<!--<xsl:attribute name="otherCardinality">
						<xsl:call-template name="xmi2xmilCardinality_12">
							<xsl:with-param name="lower" select="$thisEnd//UML:MultiplicityRange/@lower"/>
							<xsl:with-param name="upper" select="$thisEnd//UML:MultiplicityRange/@upper"/>
						</xsl:call-template>
					</xsl:attribute> -->
					<!-- collectionType attribute is only used
				     if cardinality is greater than 1. -->
					<!--<xsl:if test="$otherEnd//UML:MultiplicityRange/@upper = -1 or $otherEnd//UML:MultiplicityRange/@upper &gt; 1 or $otherEnd//UML:MultiplicityRange/@upper = '*'">
						<xsl:attribute name="collectionType">
							<xsl:choose>
								<xsl:when test="$otherEnd/UML:AssociationEnd.ordering/@xmi.value = 'ordered'">list</xsl:when>
								<xsl:otherwise>set</xsl:otherwise>-->
								<!-- bag and dictionary not implemented yet -->
					<!--		</xsl:choose>
						</xsl:attribute>
					</xsl:if>
					<xsl:attribute name="aggregationType">
						<xsl:value-of select="$thisEnd/@aggregation"/>
					</xsl:attribute>-->
					<!-- stereotype -->
					<!-- Poseidon has the stereotype on the UML:Association element -->
					<xsl:apply-templates select="UML:ModelElement.stereotype | ../../../../UML:ModelElement.stereotype"/>
					<!--<xsl:if test="$thisEnd/@isNavigable='true'">
						<xsl:attribute name="otherEnd">
							<xsl:call-template name="XMI1_2_translateID"><xsl:with-param name="id" select="$thisEndId"/></xsl:call-template>
						</xsl:attribute>
					</xsl:if>-->
					<!-- Tagged values -->
					<!--<xsl:call-template name="XMI1_2_genTaggedValues">
						<xsl:with-param name="id" select="../../@xmi.id"/>
					</xsl:call-template>-->
				</xsl:element>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="dumpCardinalityAttribs">
		<xsl:param name="cardinality"/>
		<xsl:param name="type">	
			<xsl:if test="$cardinality != '-1'">
				<xsl:text>uml:LiteralInteger</xsl:text>
			</xsl:if>
			<xsl:if test="$cardinality = '-1'">
				<xsl:text>uml:LiteralUnlimitedNatural</xsl:text>
			</xsl:if>
		</xsl:param>

		
		<xsl:attribute name="xmi:type">
			<xsl:value-of select="$type"/>
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="$cardinality"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template name="XMI1_2_getID">
		<xsl:value-of select="translate(@xmi.id, '():/$','_____')"/>
	</xsl:template>	
	<xsl:template name="XMI1_2_translateID">
		<xsl:param name="id"/>
		<xsl:value-of select="translate($id, '():/$','_____')"/>
	</xsl:template>

</xsl:stylesheet><!-- Stylus Studio meta-information - (c) 2004-2005. Progress Software Corporation. All rights reserved.
<metaInformation>
<scenarios ><scenario default="yes" name="ExportTesting1.3 Unisys.xml" userelativepaths="yes" externalpreview="no" url="ExportTesting1.3 Unisys.xml" htmlbaseurl="" outputurl="cars.uml2" processortype="internal" profilemode="0" profiledepth="" profilelength="" urlprofilexml="" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/></scenarios><MapperMetaTag><MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="..\..\..\Develop\runtime&#x2D;workspace\runtest\ServiceModel.uml2" destSchemaRoot="Model" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no" ><SourceSchema srcSchemaPath="ExportTesting1.3 Unisys.xml" srcSchemaRoot="XMI" AssociatedInstance="" loaderFunction="document" loaderFunctionUsesURI="no"/></MapperInfo><MapperBlockPosition><template match="/"></template><template match="text()|@*"></template><template name="XMI1_2_Root"></template><template name="XMI1_2_classBody"></template></MapperBlockPosition></MapperMetaTag>
</metaInformation>
-->